@@ -311,8 +311,11 @@ networkPlot <-
                                net_groups$membership,
                                as.numeric(betweenness(
                                  bsk.network, directed = F, normalized = F
-                               )))
-      names(cluster_res) <- c("vertex", "cluster", "btw_centrality")
+                               )),
+                               as.numeric(closeness(
+                                 bsk.network)),
+                               as.numeric(page.rank(bsk.network)$vector))
+      names(cluster_res) <- c("vertex", "cluster", "btw_centrality", "clos_centrality","pagerank_centrality")
       cluster_res <- cluster_res[order(cluster_res$cluster), ]
     } else {
       cluster_res <- NA
